storage

package
v0.6.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 8, 2026 License: Apache-2.0 Imports: 24 Imported by: 0

Documentation

Overview

Package storage implements the pmx pve storage command group.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Group

func Group(_ *cli.Deps) *cobra.Command

Group builds the `pmx pve storage` command and all of its sub-commands. The supplied *cli.Deps is a placeholder used only so cobra can build the command tree; live dependencies are obtained per-invocation via cli.GetDeps.

Types

This section is empty.

Jump to